@@ -9,8 +9,8 @@ def print_info() -> None:
     Print package info to stdout.
     """
     print(
-        "Type annotations for boto3.IoTDataPlane 1.26.0\nVersion:         1.26.0\nBuilder version:"
-        " 7.11.10\nDocs:           "
+        "Type annotations for boto3.IoTDataPlane 1.26.101\nVersion:         1.26.101\nBuilder"
+        " version: 7.14.4\nDocs:           "
         " https://youtype.github.io/boto3_stubs_docs/mypy_boto3_iot_data//\nBoto3 docs:     "
         " https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/iot-data.html#IoTDataPlane\nOther"
         " services:  https://pypi.org/project/boto3-stubs/\nChangelog:      "
@@ -22,7 +22,7 @@ def print_version() -> None:
     """
     Print package version to stdout.
     """
-    print("1.26.0")
+    print("1.26.101")
 
 
 def main() -> None:
