@@ -19,6 +19,7 @@ from typing import IO, Any, Dict, Mapping, Type, Union
 from botocore.client import BaseClient, ClientMeta
 from botocore.response import StreamingBody
 
+from .literals import PayloadFormatIndicatorType
 from .paginator import ListRetainedMessagesPaginator
 from .type_defs import (
     DeleteThingShadowResponseTypeDef,
@@ -162,7 +163,13 @@ class IoTDataPlaneClient(BaseClient):
         topic: str,
         qos: int = ...,
         retain: bool = ...,
-        payload: Union[str, bytes, IO[Any], StreamingBody] = ...
+        payload: Union[str, bytes, IO[Any], StreamingBody] = ...,
+        userProperties: str = ...,
+        payloadFormatIndicator: PayloadFormatIndicatorType = ...,
+        contentType: str = ...,
+        responseTopic: str = ...,
+        correlationData: str = ...,
+        messageExpiry: int = ...
     ) -> EmptyResponseMetadataTypeDef:
         """
         Publishes an MQTT message.
